@@ -1,10 +1,10 @@
 ;; -*- no-byte-compile: t; lexical-binding: nil -*-
-(define-package "unison-ts-mode" "0.2.0"
+(define-package "unison-ts-mode" "20251209.856"
   "Tree-sitter support for Unison."
   '((emacs "29.1"))
   :url "https://github.com/fmguerreiro/unison-ts-mode"
-  :commit "e31a211899e5c249a521b8b1e09f48bcc40383af"
-  :revdesc "e31a211899e5"
+  :commit "f8d291e8be9b2a3259d59e2d469660465a3d5deb"
+  :revdesc "f8d291e8be9b"
   :keywords '("languages" "unison" "tree-sitter")
   :authors '(("Filipe Guerreiro" . "filipe.m.guerreiro@gmail.com"))
   :maintainers '(("Filipe Guerreiro" . "filipe.m.guerreiro@gmail.com")))
